@@ -281,7 +281,7 @@ class Users(_defaults_.Defaults):
 
 		# check parameters.
 		if [username,email] == [None,None]:
-			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="delete")+" Define one of the following parameters [email, username].")
 
 		# delete django user.
 		response = self.django.users.delete(username=username, email=email)
@@ -465,7 +465,7 @@ class Users(_defaults_.Defaults):
 	):
 		username, email = self.__correct_username_email__(username, email)
 		if [username,email] == [None,None]:
-			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="save_data")+" Define one of the following parameters [email, username].")
 		response = self.db.save(path=self.__get_path__(email=email, username=username, create=True), data=data, overwrite=overwrite)
 		if response.error != None: return response
 		return dev0s.response.success(f"Successfully saved the data of user [{email}].")
@@ -941,7 +941,7 @@ class Users(_defaults_.Defaults):
 	def load_password(self, email=None, username=None):
 		username, email = self.__correct_username_email__(username, email)
 		if [username,email] == [None,None]:
-			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="load_password")+" Define one of the following parameters [email, username].")
 		response = self.load_data(email=email, username=username)
 		if not response.success: return response
 		data = response.data
@@ -955,7 +955,7 @@ class Users(_defaults_.Defaults):
 	def save_password(self, email=None, username=None, password=None):
 		username, email = self.__correct_username_email__(username, email)
 		if [username,email] == [None,None]:
-			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="save_password")+" Define one of the following parameters [email, username].")
 		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="save_password"),
 			parameters={
